@@ -5,7 +5,7 @@ from .nodes import *
 is_expression = frozenset([
     PysNumberNode, PysStringNode, PysKeywordNode, PysIdentifierNode, PysDictionaryNode, PysSetNode, PysListNode,
     PysTupleNode, PysAttributeNode, PysSubscriptNode, PysCallNode, PysChainOperatorNode, PysTernaryOperatorNode,
-    PysBinaryOperatorNode, PysUnaryOperatorNode, PysMatchNode, PysFunctionNode, PysEllipsisNode
+    PysBinaryOperatorNode, PysUnaryOperatorNode, PysIncrementalNode, PysMatchNode, PysFunctionNode, PysEllipsisNode
 ]).__contains__
 
 is_statement = frozenset([
@@ -28,10 +28,6 @@ is_equals = frozenset([
     TOKENS['EQUAL'], TOKENS['EQUAL-COLON']
 ]).__contains__
 
-is_incremental = frozenset([
-    TOKENS['DOUBLE-PLUS'], TOKENS['DOUBLE-MINUS']
-]).__contains__
-
 is_blacklist_python_builtins = frozenset([
     'IndentationError', 'TabError', 'breakpoint', 'compile', 'copyright', 'credits', 'dir', 'eval', 'exec', 'help',
     'globals', 'license', 'locals', 'vars'
